@@ -419,10 +419,6 @@ p, li { white-space: pre-wrap; }
         <source>&amp;Help</source>
         <translation>&amp;Nápověda</translation>
     </message>
-    <message>
-        <source>Actions Panel</source>
-        <translation type="obsolete">Panel činností</translation>
-    </message>
     <message>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
@@ -719,18 +715,6 @@ p, li { white-space: pre-wrap; }
         <source>No rotation</source>
         <translation>Žádné otočení</translation>
     </message>
-    <message>
-        <source>+ 90°</source>
-        <translation type="vanished">+ 90°</translation>
-    </message>
-    <message>
-        <source>- 90°</source>
-        <translation type="vanished">- 90°</translation>
-    </message>
-    <message>
-        <source>180°</source>
-        <translation type="vanished">180°</translation>
-    </message>
     <message>
         <source>Flip image:</source>
         <translation>Obrátit obrázek:</translation>
