@@ -167,10 +167,6 @@ p, li { white-space: pre-wrap; }
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Follow Converseen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Converseenをフォロー:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
-    <message>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;If you appreciate this work and would like to support the project, you are welcome to donate via PayPal or Flattr&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;このアプリが気に入ったらプロジェクトをサポートするための PayPal や Flattr での寄付を歓迎します&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
     <message>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
@@ -250,15 +246,15 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Check all</source>
-        <translation>すべてチェック</translation>
+        <translation>全てチェック</translation>
     </message>
     <message>
         <source>Uncheck</source>
-        <translation>チェックをはずす</translation>
+        <translation>チェックを外す</translation>
     </message>
     <message>
         <source>Uncheck all</source>
-        <translation>すべてのチェックをはずす</translation>
+        <translation>全てチェックを外す</translation>
     </message>
     <message>
         <source>Import multipage document</source>
@@ -273,7 +269,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Please, restart Converseen to apply current language!</source>
-        <translation>変更した言語を適用するために再起動!</translation>
+        <translation>言語の変更を適用するためにConverseenを再起動してください!</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -301,19 +297,19 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>As&amp;k first</source>
-        <translation type="unfinished"></translation>
+        <translation>最初に確認する(&amp;K)</translation>
     </message>
     <message>
         <source>O&amp;verwrite all existing images</source>
-        <translation type="unfinished"></translation>
+        <translation>既存のイメージを全て上書きする(&amp;O)</translation>
     </message>
     <message>
         <source>Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>アップデート</translation>
     </message>
     <message>
         <source>Checks for updates automatically</source>
-        <translation type="unfinished"></translation>
+        <translation>アップデートを自動的に確認する</translation>
     </message>
 </context>
 <context>
@@ -324,11 +320,11 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Png compression level</source>
-        <translation>Png圧縮レベル</translation>
+        <translation>PNG圧縮レベル</translation>
     </message>
     <message>
         <source>Jpeg compression level</source>
-        <translation>Jpeg圧縮レベル</translation>
+        <translation>JPEG圧縮レベル</translation>
     </message>
     <message>
         <source>Quality 0 - 100:</source>
@@ -355,23 +351,23 @@ p, li { white-space: pre-wrap; }
     <name>DialogShowUpdateMsg</name>
     <message>
         <source>Dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>ダイアログ</translation>
     </message>
     <message>
         <source>TextLabel</source>
-        <translation type="unfinished"></translation>
+        <translation>テキストラベル</translation>
     </message>
     <message>
         <source>Don&apos;t show again</source>
-        <translation type="unfinished"></translation>
+        <translation>今後表示しない</translation>
     </message>
     <message>
         <source>Update Now</source>
-        <translation type="unfinished"></translation>
+        <translation>今すぐアップデート</translation>
     </message>
     <message>
         <source>Not Now</source>
-        <translation type="unfinished"></translation>
+        <translation>今はしない</translation>
     </message>
 </context>
 <context>
@@ -419,10 +415,6 @@ p, li { white-space: pre-wrap; }
         <source>&amp;Help</source>
         <translation>ヘルプ(&amp;H)</translation>
     </message>
-    <message>
-        <source>180°</source>
-        <translation type="vanished">180°</translation>
-    </message>
     <message>
         <source>Check selected items</source>
         <translation>選択したアイテムをチェック</translation>
@@ -499,18 +491,6 @@ p, li { white-space: pre-wrap; }
         <source>Horizontally</source>
         <translation>水平</translation>
     </message>
-    <message>
-        <source>+ 90°</source>
-        <translation type="vanished">+ 90°</translation>
-    </message>
-    <message>
-        <source>- 90°</source>
-        <translation type="vanished">- 90°</translation>
-    </message>
-    <message>
-        <source>Actions Panel</source>
-        <translation type="obsolete">操作パネル</translation>
-    </message>
     <message>
         <source>Open output directory</source>
         <translation>出力ディレクトリーを開く</translation>
@@ -565,7 +545,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Check all items</source>
-        <translation>すべてチェック</translation>
+        <translation>全てチェック</translation>
     </message>
     <message>
         <source>Start with:</source>
@@ -577,7 +557,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Overwrite all</source>
-        <translation>すべて上書き</translation>
+        <translation>全て上書き</translation>
     </message>
     <message>
         <source>Flip image:</source>
@@ -633,7 +613,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Check a&amp;ll</source>
-        <translation>すべてチェック(&amp;l)</translation>
+        <translation>全てチェック(&amp;L)</translation>
     </message>
     <message>
         <source>&amp;Convert</source>
@@ -693,7 +673,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Remove &amp;all</source>
-        <translation>全て削除(&amp;a)</translation>
+        <translation>全て削除(&amp;A)</translation>
     </message>
     <message>
         <source>Dimensions</source>
@@ -729,7 +709,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Uncheck all &amp;items</source>
-        <translation>すべてチェックを外す(&amp;i)</translation>
+        <translation>全てチェックを外す(&amp;I)</translation>
     </message>
     <message>
         <source>Rotate and flip</source>
@@ -769,55 +749,51 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Import windows icon (*.ico)</source>
-        <translation>Windows アイコン (*.ico)のインポート</translation>
+        <translation>Windowsアイコン (*.ico) のインポート</translation>
     </message>
     <message>
         <source>Import windows icon (*.ico *.icon)</source>
         <translation>Windowsアイコン (*.ico *.icon)</translation>
     </message>
-    <message>
-        <source>Donate via Flattr</source>
-        <translation type="vanished">Flattr で寄付</translation>
-    </message>
     <message>
         <source>Prefi&amp;x/Suffix</source>
-        <translation type="unfinished"></translation>
+        <translation>接頭辞/接尾辞(&amp;X)</translation>
     </message>
     <message>
         <source>Progressi&amp;ve Number</source>
-        <translation type="unfinished"></translation>
+        <translation>連番(&amp;V)</translation>
     </message>
     <message>
         <source>&amp;Donate via Paypal</source>
-        <translation type="unfinished"></translation>
+        <translation>Paypalで寄付(&amp;D)</translation>
     </message>
     <message>
         <source>&amp;Report bug...</source>
-        <translation type="unfinished"></translation>
+        <translation>バグを報告(&amp;R)...</translation>
     </message>
     <message>
         <source>Check if a new version of Converseen is available</source>
-        <translation type="unfinished"></translation>
+        <translation>Converseenの新しいバージョンが利用可能か確認する</translation>
     </message>
     <message>
         <source>&amp;Check for updates</source>
-        <translation type="unfinished"></translation>
+        <translation>アップデートを確認(&amp;C)</translation>
     </message>
     <message>
         <source>Actio&amp;ns Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>動作パネル(&amp;N)</translation>
     </message>
     <message>
         <source>+ &amp;90°</source>
-        <translation type="unfinished"></translation>
+        <translation>+ 90°(&amp;9)</translation>
     </message>
     <message>
         <source>- 9&amp;0°</source>
-        <translation type="unfinished">- 90° {9&amp;0°?}</translation>
+        <translation>- 90°(&amp;0)</translation>
     </message>
     <message>
         <source>&amp;180°</source>
-        <translation type="unfinished"></translation>
+        <translation>180°(&amp;1)</translation>
     </message>
 </context>
 <context>
@@ -969,7 +945,8 @@ Abortで操作の取り消し。</translation>
     <message>
         <source>A new version of %1 is available!
 Would you download it?</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1 の新しいバージョンが利用可能です!
+ダウンロードしますか?</translation>
     </message>
 </context>
 <context>
